readimf-package: readimf: Access International Monetary Fund Data via the...

readimf-packageR Documentation

readimf: Access International Monetary Fund Data via the 'SDMX' 3.0 API

Description

Download macroeconomic and financial statistics from the International Monetary Fund data portal (https://data.imf.org), served through an 'SDMX' 3.0 REST API. Provides a tidy interface to the Fund's flagship databases, beginning with the World Economic Outlook, and reads the compact 'SDMX-CSV' representation of each query for fast, dependency-light parsing.

Author(s)

Maintainer: Charles Coverdale charlesfcoverdale@gmail.com

See Also

Useful links:


readimf documentation built on June 15, 2026, 5:07 p.m.