| readimf-package | R Documentation |
Download macroeconomic and financial statistics from the International Monetary Fund data portal (https://data.imf.org), served through an 'SDMX' 3.0 REST API. Provides a tidy interface to the Fund's flagship databases, beginning with the World Economic Outlook, and reads the compact 'SDMX-CSV' representation of each query for fast, dependency-light parsing.
Maintainer: Charles Coverdale charlesfcoverdale@gmail.com
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.